@@ -4,7 +4,12 @@
 #' @keywords internal
 "_PACKAGE"
 
-#' @importFrom ggplot2 autoplot labs ggplot geom_line
+#' @importFrom stats quantile
+#' @importFrom evd fpot pgpd
+#' @importFrom ggplot2 autoplot labs ggplot geom_line geom_segment
 #' @importFrom ggplot2 geom_contour_filled geom_contour scale_fill_manual
+#' @importFrom lookout mvscale
 #' @export
 ggplot2::autoplot
+#' @export
+lookout::mvscale
